@@ -188,6 +188,17 @@ long _AVLListX::GetDataByKey(BaseRefConst key) const {
     return GetXtra(f);
 }
 
+//______________________________________________________________
+
+long _AVLListX::GetDataByKey(long key) const {
+    long f = FindLong (key);
+    if (f < 0L) {
+        return -1L;
+    }
+    return GetXtra(f);
+}
+
+
 //______________________________________________________________
 
 long _AVLListX::FindAndGetXtra(BaseRefConst key, long default_value) const {
