@@ -96,17 +96,21 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #define  HY_VARIABLE_CHANGED                        0x0002
 #define  HY_VARIABLE_CHANGED_CLEAR                  0xFFFD
 #define  HY_DEP_V_COMPUTED                          0x0004
+#define  HY_DEP_V_COMPUTED_CLEAR                    0xFFFB
 #define  HY_DEP_V_INSPECTED                         0x0008
 #define  HY_DEP_V_MODIFIED                          0x0010
+#define  HY_DEP_V_MODIFIED_CLEAR                    0xFFEF
 #define  HY_DEP_V_MODIFIED_CATS                     0x0020
 #define  HY_VC_NO_CHECK                             0x0040 // do not check this variable container in
 // NeedToExponentiate
 #define  HY_VARIABLE_NOTSET                         0x0080
 #define  HY_VARIABLE_COMPUTING                      0x0100
+#define  HY_VARIABLE_SET_EXTERNALLY                 0x0200
 
 #define  HY_VARIABLE_SET                            0xFF7F
 #define  HY_DEP_V_INSPECTED_CLR                     0xFFF7
 #define  HY_VARIABLE_COMPUTING_CLR                  0xFEFF
+#define  HY_VARIABLE_SET_EXTERNALLY_CLR             0xFDFF
 #define  HY_VC_CLR_NO_CHECK                         0xFFBF
 #define  HY_DEP_CLEAR_MASK                          0xFFC7
 #define  HY_HY_VARIABLE_CHANGED_CLEAR               0xFFFC
